server {
    server_name maven.mcmoddev.com;

    listen 80;
    listen [::]:80;

    return 301 https://$server_name$request_uri;
}

server {
    server_name maven.mcmoddev.com;

    listen 443 http2;
    listen [::]:443 http2;

    # HSTS
    add_header Strict-Transport-Security "max-age=31536000; includeSubDomains";

    # HPKP
    add_header Public-Key-Pins 'pin-sha256="C5+lpZ7tcVwmwQIMcRtPbsQtWLABXhQzejna0wHFr8M="; pin-sha256="jQJTbIh0grw0/1TkHSumWb+Fs0Ggogr621gT3PvPKG0="; pin-sha256="5VReIRNHJBiRxVSgOTTN6bdJZkpZ0m1hX+WPd5kPLQM="; pin-sha256="Vjs8r4z+80wjNcr1YKepWQboSIRi63WsWXhIMN+eWys="; pin-sha256="noCQrs1qozwlji1bDn9ysi9TBb+tXhZRFEtoTJgfFy4="; max-age=5184000; includeSubDomains';

    add_header X-Content-Type-Options  "nosniff";
    add_header X-Frame-Options "SAMEORIGIN";
    add_header X-XSS-Protection "1; mode=block";
#    add_header Content-Security-Policy "base-uri 'self'; frame-ancestors 'none'; form-action 'self'; default-src 'none'; font-src 'self'; img-src 'self'; media-src 'self'; object-src 'self'; script-src 'self'; style-src 'self'; upgrade-insecure-requests"; #block-all-mixed-content; script-src 'report-sample' 
    add_header Expect-CT "max-age=300, enforce";
    add_header Referrer-Policy "same-origin";
    add_header Feature-Policy "geolocation 'self'; microphone 'self'; camera 'self'; magnetometer 'self'; gyroscope 'self'; payment 'none'";

    ssl on;
#   ssl_ciphers 'EECDH+AES256GCM:EDH+AES256GCM:AES256+EECDH:AES256+EDH:AES128+EECDH:AES128+EDH';
    # RSA
    ssl_certificate /etc/letsencrypt/live/maven.mcmoddev.com/fullchain.pem;
    ssl_certificate_key /etc/letsencrypt/live/maven.mcmoddev.com/privkey.pem;
    # ECDSA
   #  ssl_certificate /etc/letsencrypt/maven.mcmoddev.com_ecc/fullchain.cer;
   #  ssl_certificate_key /etc/letsencrypt/maven.mcmoddev.com_ecc/maven.mcmoddev.com.key;

    ssl_trusted_certificate /etc/letsencrypt/live/maven.mcmoddev.com/chain.pem;

    root /var/www/maven.mcmoddev.com;
    index index.html index.php /_h5ai/public/index.php;

    location / {
        try_files $uri $uri/ =404;
    }

    location ~ \.php$ {
        try_files $uri =404;
        fastcgi_pass unix:/run/php/php7.4-fpm.sock;
        fastcgi_index index.php;
        fastcgi_param SCRIPT_FILENAME $document_root$fastcgi_script_name;
        include fastcgi_params;
    }
}
