server {
    server_name mcmoddev.com www.mcmoddev.com;

    listen 80;
    listen [::]:80;

    return 301 https://$server_name$request_uri;
}

server {
    server_name mcmoddev.com www.mcmoddev.com;

    listen 443 http2;
    listen [::]:443 http2;

    # HSTS
    add_header Strict-Transport-Security "max-age=31536000; includeSubDomains";

    # HPKP
    add_header Public-Key-Pins 'pin-sha256="C5+lpZ7tcVwmwQIMcRtPbsQtWLABXhQzejna0wHFr8M="; pin-sha256="jQJTbIh0grw0/1TkHSumWb+Fs0Ggogr621gT3PvPKG0="; pin-sha256="5VReIRNHJBiRxVSgOTTN6bdJZkpZ0m1hX+WPd5kPLQM="; pin-sha256="Vjs8r4z+80wjNcr1YKepWQboSIRi63WsWXhIMN+eWys="; pin-sha256="noCQrs1qozwlji1bDn9ysi9TBb+tXhZRFEtoTJgfFy4="; max-age=5184000; includeSubDomains' always;

    ssl on;
    # RSA
    ssl_certificate /etc/letsencrypt/live/mcmoddev.com/fullchain.pem;
    ssl_certificate_key /etc/letsencrypt/live/mcmoddev.com/privkey.pem;
    # ECDSA
    ssl_certificate /etc/letsencrypt/mcmoddev.com_ecc/fullchain.cer;
    ssl_certificate_key /etc/letsencrypt/mcmoddev.com_ecc/mcmoddev.com.key;

    ssl_trusted_certificate /etc/letsencrypt/live/mcmoddev.com/chain.pem;

    root /var/www/mcmoddev.com;
    index index.php index.html;

    error_page 404 /404.html;

    location / {
        try_files $uri $uri/ =404;
    }

    location ~ \.php$ {
        try_files $uri =404;
        fastcgi_split_path_info ^(.+\.php)(/.+)$;
        fastcgi_pass unix:/run/php/php7.4-fpm.sock;
        fastcgi_index index.php;
        fastcgi_param  SCRIPT_FILENAME  $document_root$fastcgi_script_name;
        include /etc/nginx/fastcgi_params;
    }
}
